@@ -18,7 +18,7 @@ class GetDivOfAddressCUDA(CustomKernel):
 
     self._use_torch_in_cupy_malloc()
     self.stream = Stream(torch.cuda.current_stream().cuda_stream)
-    with open(get_absolute_path("GetDivOfAddressKernel.cu"), "r") as f:
+    with open(get_absolute_path("kernels", "GetDivOfAddressKernel.cu"), "r") as f:
       self.kernel = f.read()
     kernel = (self.kernel
       .replace("_TA_", str(ta))
